@@ -15,15 +15,15 @@ class DiagramsWindow : public QDockWidget
 {
     Q_OBJECT
 public:
-    explicit DiagramsWindow(const QString &title, QWidget *parent = 0);
+    explicit DiagramsWindow(const QString &title, QWidget *parent = nullptr);
     ~DiagramsWindow();
 
-signals:
+Q_SIGNALS:
 
-public slots:
+public Q_SLOTS:
     void modified();
 
-protected slots:
+protected Q_SLOTS:
     void slotDiagramsDoubleClicked(QModelIndex index);
     void slotDiagramsClicked(QModelIndex index);
 
